;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "ob-athena" "2.1.5"
  "Run AWS Athena queries from Org Babel."
  '((emacs "26.1"))
  :url "https://github.com/will-abb/aws-athena-babel"
  :commit "dd46b58566129ab9a2c93d7702d90dea6900fddb"
  :revdesc "v2.1.5-0-gdd46b5856612"
  :keywords '("aws" "athena" "org" "babel" "sql" "tools")
  :authors '(("Williams Bosch-Bello" . "williamsbosch@gmail.com"))
  :maintainers '(("Williams Bosch-Bello" . "williamsbosch@gmail.com")))
